package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjGcjbsjMapper;
import com.zjsgfa.project.zjsgfa.domain.SjGcjbsj;
import com.zjsgfa.project.zjsgfa.service.ISjGcjbsjService;

/**
 * 工程基本数据Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-02-02
 */
@Service
public class SjGcjbsjServiceImpl implements ISjGcjbsjService 
{
    @Autowired
    private SjGcjbsjMapper sjGcjbsjMapper;

    /**
     * 查询工程基本数据
     * 
     * @param id 工程基本数据主键
     * @return 工程基本数据
     */
    @Override
    public SjGcjbsj selectSjGcjbsjById(Long id)
    {
        return sjGcjbsjMapper.selectSjGcjbsjById(id);
    }

    /**
     * 查询工程基本数据列表
     * 
     * @param sjGcjbsj 工程基本数据
     * @return 工程基本数据
     */
    @Override
    public List<SjGcjbsj> selectSjGcjbsjList(SjGcjbsj sjGcjbsj)
    {
        return sjGcjbsjMapper.selectSjGcjbsjList(sjGcjbsj);
    }

    /**
     * 新增工程基本数据
     * 
     * @param sjGcjbsj 工程基本数据
     * @return 结果
     */
    @Override
    public int insertSjGcjbsj(SjGcjbsj sjGcjbsj)
    {

        return sjGcjbsjMapper.insertSjGcjbsj(sjGcjbsj);
    }

    /**
     * 修改工程基本数据
     * 
     * @param sjGcjbsj 工程基本数据
     * @return 结果
     */
    @Override
    public int updateSjGcjbsj(SjGcjbsj sjGcjbsj)
    {
        return sjGcjbsjMapper.updateSjGcjbsj(sjGcjbsj);
    }

    /**
     * 批量删除工程基本数据
     * 
     * @param ids 需要删除的工程基本数据主键
     * @return 结果
     */
    @Override
    public int deleteSjGcjbsjByIds(Long[] ids)
    {
        return sjGcjbsjMapper.deleteSjGcjbsjByIds(ids);
    }

    /**
     * 删除工程基本数据信息
     * 
     * @param id 工程基本数据主键
     * @return 结果
     */
    @Override
    public int deleteSjGcjbsjById(Long id)
    {
        return sjGcjbsjMapper.deleteSjGcjbsjById(id);
    }
}
