package com.zjsgfa.project.zjsgfa.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zjsgfa.framework.aspectj.lang.annotation.Log;
import com.zjsgfa.framework.aspectj.lang.enums.BusinessType;
import com.zjsgfa.project.zjsgfa.domain.SjGcjbsj;
import com.zjsgfa.project.zjsgfa.service.ISjGcjbsjService;
import com.zjsgfa.framework.web.controller.BaseController;
import com.zjsgfa.framework.web.domain.AjaxResult;
import com.zjsgfa.common.utils.poi.ExcelUtil;
import com.zjsgfa.framework.web.page.TableDataInfo;

/**
 * 工程基本数据Controller
 * 
 * @author ruoyi
 * @date 2026-02-02
 */
@RestController
@RequestMapping("/system/SjGcjbsj")
public class SjGcjbsjController extends BaseController
{
    @Autowired
    private ISjGcjbsjService sjGcjbsjService;

    /**
     * 查询工程基本数据列表
     */
    //@PreAuthorize("@ss.hasPermi('system:SjGcjbsj:list')")
    @GetMapping("/list")
    public TableDataInfo list(SjGcjbsj sjGcjbsj)
    {
        startPage();
        List<SjGcjbsj> list = sjGcjbsjService.selectSjGcjbsjList(sjGcjbsj);
        return getDataTable(list);
    }

    /**
     * 导出工程基本数据列表
     */
    //@PreAuthorize("@ss.hasPermi('system:SjGcjbsj:export')")
    @Log(title = "工程基本数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SjGcjbsj sjGcjbsj)
    {
        List<SjGcjbsj> list = sjGcjbsjService.selectSjGcjbsjList(sjGcjbsj);
        ExcelUtil<SjGcjbsj> util = new ExcelUtil<SjGcjbsj>(SjGcjbsj.class);
        util.exportExcel(response, list, "工程基本数据数据");
    }

    /**
     * 获取工程基本数据详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:SjGcjbsj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        SjGcjbsj sjGcjbsj = sjGcjbsjService.selectSjGcjbsjById(id);
        if(sjGcjbsj==null){
            sjGcjbsj=new SjGcjbsj();
        }
        return success(sjGcjbsj);
    }

    /**
     * 新增工程基本数据
     */
    //@PreAuthorize("@ss.hasPermi('system:SjGcjbsj:add')")
    @Log(title = "工程基本数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SjGcjbsj sjGcjbsj)
    {
        return toAjax(sjGcjbsjService.insertSjGcjbsj(sjGcjbsj));
    }

    /**
     * 修改工程基本数据
     */
    //@PreAuthorize("@ss.hasPermi('system:SjGcjbsj:edit')")
    @Log(title = "工程基本数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SjGcjbsj sjGcjbsj)
    {
        return toAjax(sjGcjbsjService.updateSjGcjbsj(sjGcjbsj));
    }

    /**
     * 删除工程基本数据
     */
    //@PreAuthorize("@ss.hasPermi('system:SjGcjbsj:remove')")
    @Log(title = "工程基本数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sjGcjbsjService.deleteSjGcjbsjByIds(ids));
    }
}
